package de.econda.example;

import android.os.Bundle;
import android.view.View;

import androidx.appcompat.app.AppCompatActivity;
import androidx.viewpager.widget.ViewPager;

import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.google.android.material.snackbar.Snackbar;
import com.google.android.material.tabs.TabLayout;

import de.econda.droid.PageView;
import de.econda.droid.Session;
import de.econda.example.ui.main.SectionsPagerAdapter;

public class MainActivity extends AppCompatActivity {

    /**
     * Storing the econdaAnalyticsSession in Activity for later reuse.
     */
    private Session econdaAnalyticsSession;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Get shared econdaAnalyticsSession from the Application and store it in private field for later reuse
        MyApplication application = (MyApplication) getApplication();
        econdaAnalyticsSession = application.getEcondaAnalyticsSession();

        SectionsPagerAdapter sectionsPagerAdapter = new SectionsPagerAdapter(this, getSupportFragmentManager());
        ViewPager viewPager = findViewById(R.id.view_pager);
        viewPager.setAdapter(sectionsPagerAdapter);
        TabLayout tabs = findViewById(R.id.tabs);
        tabs.setupWithViewPager(viewPager);
        FloatingActionButton fab = findViewById(R.id.fab);

        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                sendPageView("MainActivity/FloatingActionButton");
                Snackbar.make(view, "Tracking sent", Snackbar.LENGTH_LONG)
                        .setAction("Action", null).show();
            }
        });

        // When the visible image changes, send a screen view hit.
        viewPager.addOnPageChangeListener(new ViewPager.SimpleOnPageChangeListener() {
            @Override
            public void onPageSelected(int position) {
                sendPageView("MainActivity/PageSelected/" + position);
            }
        });

        sendPageView("MainActivity/Start");

    }

    public void sendPageView(String content) {

        PageView pageView = new PageView()
                .addContent(content);

        econdaAnalyticsSession.addPageView(pageView);

    }

    public Session getEcondaAnalyticsSession() {
        return econdaAnalyticsSession;
    }
}