package de.econda.example;


import android.app.Application;

import de.econda.droid.PrivacySettings;
import de.econda.droid.Session;
import de.econda.droid.Settings;
import de.econda.droid.SettingsBuilder;

public class MyApplication extends Application {

    private Session econdaAnalyticsSession;

    @Override
    public void onCreate() {
        super.onCreate();

        // Account registration key, retrieved from econda support.
        String clientKey = "xxxxxxxx-xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx";
		/*
		Retrieve new Econda Analytics Session in Batch Mode.

		Session Object must be stored in your Application Object for later usage.

		Please do not create always a new Session,
		this would result in several distinct Sessions (Visits) in Econda Analytics data.

		Data of all PageViews is collected.
		In batch mode data is only submitted, if the timeout exceeds or you call trackerSession.submitBatch() manually.
		If you always want to submit the generated data immediately to the tracking server, then use:
		econdaAnalyticsSession = TrackingSession.getInstance(this, clientKey, false); (without parameter batchAutoTransmitTimeout)

		Parameter 1: context: Activity and Application are context objects. In case of Activity, we automatically use its ApplicationContext.
		Parameter 2: clientKey: Your client key is provided by econda. Please contact your econda ecommerce consultant.
		Parameter 3: boolean secure: Use HTTPS
		Parameter 4: boolean visitorAnalytics: Do use Visitors Analytics, the opposite would be only measurement from visits but not visitors.
		Parameter 5: int batchAutoTransmitTimeout: In case requests are first collected and then submitted as batch. Timeout in seconds. Otherwise ommit parameter or use -1 for immediate transmission.
		*/
        Settings settings = new SettingsBuilder(clientKey)
                .setDefaultPrivacySettingsNewUser(PrivacySettings.ANONYM)
                .setBatchAutoTransmitTimeout(10)
                .build();

        econdaAnalyticsSession = Session.createNewInstance(this, settings);
        // if you want to sample the data use:
        // econdaAnalyticsSession.setSamplingRate(2);
    }

    public Session getEcondaAnalyticsSession() {
        return econdaAnalyticsSession;
    }

}
