﻿Econda Analytics Android SDK
============================

1. First ensure that the application has the permission to access the Internet and to retrieve the network state.

    Please add the following tags as child elements to the manifest tag in the Androidmanifest.xml of the app module:

	    <uses-permission android:name="android.permission.INTERNET"/>
	    <uses-permission android:name="android.permission.ACCESS_NETWORK_STATE"/>

2. Include the econda-droid.aar library as module in Android Studio.

    In Android Studio:
    
       Go to File > New > New Module.  
	    Click on Import .JAR/.AAR Package.

	Select the econda-droid.aar (should be in folder outside project)  
	Name of subproject: econda-droid
	
	A new module is created and the .aar-file is automatically copied into the new module inside the project structure.

3.  In the build.gradle script of the app module, add the new library module as dependency.

	Under dependencies add:  

        implementation project(':econda-droid')

4.  Using the API   

	Create at application startup a new Session and store it in your central Application object.  
	In the onCreate() method of your Application-Object you could create the econda Session:  

	First create a Settings-Object by using the SettingsBuilder:

	    Settings settings = new SettingsBuilder(clientKey)
                    .setDefaultPrivacySettingsNewUser(PrivacySettings.ANONYM)
                    .setBatchAutoTransmitTimeout(10)
                    .build();

    Then you can create the Session-Object and store it as field of your Application-Object:

        this.econdaAnalyticsSession = Session.createNewInstance(this, settings);

	Add a public getter method to your Application-Class in which you return the Session instance.
	(In the example source code called getEcondaAnalyticsSession())

	If you do not have a central application class yet, proceed as follows:

	New Class 'MyApplication' extends Application.
	This class has to be referenced using the android:name attribute in the AndroidManifest.xml of the app module from the application tag.

	    <application android:name=".MyApplication" ....

	Within an Activity class, you can access your Session as follows:

	    Session session = ((MyApplication)getApplication()).getEcondaAnalyticsSession();

	You can store the session and reuse it over very long durations.
	We will make automatic an Session break if duration between PageViews is longer than 30 minutes (default setting).

5.  Configuration of the Econda Analytics Android-API  

	The Session is configured by the Settings-Object while creating it.
	Additional there are some Methods you can call after creation of the object.

	In the Settings-Object you will find following configuration possibilities:

	* PrivacySettings defaultPrivacySettingsNewUser: PrivacySetting used for new Sessions without stored Settings
	* clientKey: Your client key is provided by econda. Please contact your econda ecommerce consultant.
	* secureTransmit: Use HTTPS
	* customHostName: Is saved as Hostname in econda Analytics. If not otherwise stated, the hostname is: “Android/” + app name.
	* batchAutoTransmitTimeout: In case requests are first collected and then submitted as batch. Timeout in seconds. Otherwise use -1 for immediate transmission.
	* samplingRate: if set to a value n>1 only each n-th user will be tracked.

6. Generate a PageView data object

	Within the Activity class, generate a PageView object:

        PageView pageView = new PageView();

	Add properties to the object:

	    pageView.addProperty("content", "test");

	Add PageView to the session:

	    session.addPageView(pageView);

	The session object now contains PageView data.

	Depending on the settings, the data will or will not be transferred immediatly to the econda server.
	If you have configured the batchAutoTransmitTimeout to a number > 0,
	the session tries to wait this time until the transmission will be done.
	However, you can always force an immediate data submission with:

	    session.submitBatch();

	Every single data transmission increases the energy consumption.
	Frequent sending can reduce the battery life of the mobile phone.
	In order to conserve some battery life, you can gather PageView data and send it batched at once.
	it is also recommended to combine the econda data to be sent with an already existing Internet request that is being used anyway.

7.  Update and store changes in PrivacySettings  

    You can change and persist PrivacySettings of the currently active session by calling

        session.changePrivacySettings(newPrivacySettings);

    The settings will be applied immediately and persisted for later use.

    There are 4 predefined PrivacySettings:

    * *PrivacySettings.DO_NOT_TRACK* : No tracking will be done
    * *PrivacySettings.CACHE* : Cache all data submitted to the session-Object for later usage, but do not transmit anything until the user commited to other privacy settings.
    * *PrivacySettings.ANONYM* : Try to actively anonimize the given data and even stop using IP-Adress for geo-location.
    * *PrivacySettings.FULL* : The given data is transmitted as is. If you submit all data in anonymized way, the stored data will be anonym. IP-Adress is used for Geo-Location.

8.  The onPause() method of the Activity can be used to submit the data collected in the session to a later point in time.
	To do so, use the submitBatch() method from the session.

        @Override
        protected void onPause() {
            session.submitBatch();
            super.onPause();
        }

9. You can as well use the onStop() handler alternatively instead of onPause().

	We recommend not to use the onDestroy handler since data will be lost when the application is started.

	You can call session.submitBatch() after adding a PageView to the session to force immediate sending of specific data parts.
	For example, if you want to track a click on a button:

       button.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                PageView pageView = new PageView();
                pageView.addContent("Android/button/test");
                session.addPageView(pageView);
                // force immediate data transmission
                session.submitBatch();
            }
        });

10. Force session break  

    If you want to start a new session, you can enforce it by calling 
    `session.startNextSession()`    
    on the existing session or create a new Session object.

11. Important note: Data transmission is always asynchronous and does not slow down the calling thread.

    The calling thread handles layout rendering, event handling and so on.
    This is why the econda library always uses a separate thread for the time-consuming data transmission via network.
    This does not cause the calling thread to slow down.

12. Steps to install the hybrid webview example:  
    Copy the example html file ExamplePageOnWebserver.html to the root of your local webserver (e.g. Tomcat root)
	To use http instead of https add following attribute

        android:usesCleartextTraffic="true"

    to the application tag of AndroidManifest.xml, like
    
	     <application
			android:usesCleartextTraffic="true"
			android:name=".MyApplication"
			...
			
	Additionally you must change the URL to your local Webserver.  
	localhost as domainname will not work.  
    In onCreate() of the class WebViewActivity replace URL in the webView.loadUrl call 
    to your local server IP-Address, e.g.:
    
            webView.loadUrl("http://<your.IP.address>:8080/ExamplePageOnWebserver.html");

